summaryrefslogtreecommitdiffstats
path: root/src/arch/i386/prefix/pxeprefix.S
diff options
context:
space:
mode:
Diffstat (limited to 'src/arch/i386/prefix/pxeprefix.S')
-rw-r--r--src/arch/i386/prefix/pxeprefix.S13
1 files changed, 8 insertions, 5 deletions
diff --git a/src/arch/i386/prefix/pxeprefix.S b/src/arch/i386/prefix/pxeprefix.S
index 32ff29614..d1eb962f5 100644
--- a/src/arch/i386/prefix/pxeprefix.S
+++ b/src/arch/i386/prefix/pxeprefix.S
@@ -318,7 +318,7 @@ print_free_basemem:
*****************************************************************************
*/
finished:
- jmp run_etherboot
+ jmp run_gpxe
/*****************************************************************************
* Subroutine: print segment:offset address
@@ -554,11 +554,11 @@ flags: .word UNDI_FL_STARTED
.equ undi_device_size, ( . - undi_device )
/*****************************************************************************
* Run Etherboot main code
*****************************************************************************
*/
-run_etherboot:
- /* Install Etherboot */
+run_gpxe:
+ /* Install gPXE */
call install
/* Set up real-mode stack */
@@ -585,7 +585,10 @@ run_etherboot:
pushl $main
pushw %cs
call prot_call
- popl %eax /* discard */
+ popl %ecx /* discard */
+
+ /* Uninstall gPXE */
+ call uninstall
/* Boot next device */
int $0x18
@@ -554,11 +554,11 @@ flags: .word UNDI_FL_STARTED
.equ undi_device_size, ( . - undi_device )
/*****************************************************************************
- * Run Etherboot main code
+ * Run gPXE main code
*****************************************************************************
*/